
-------------------------------------------------------------------------------------------------

pcwDisplayWindow=Turbine.UI.Lotro.Window();
pcwDisplayWindow:SetSize(320, 400);
pcwDisplayWindow:SetPosition(60, Turbine.UI.Display:GetHeight()/2-300); 
pcwDisplayWindow:SetText("Per Character Wallet");
pcwDisplayWindow:SetZOrder(1);


-------------------------------------------------------------------------------------------------


pcwDisplayWindow.VisibleChanged = function()

	UpdateDisplayWindowValues();

end


-------------------------------------------------------------------------------------------------

PluginIsLoaded = false;

walletSize = 0; -- used to track initialization
currencyPreviousValues = {};

-- Update is used as a workaround for the fact that the wallet isn't fully initialized when plugins are
-- loaded, so I need to keep watching for pre-existing currencies to show up as the game finishes loading.
pcwDisplayWindow.Update=function()

	if not PluginIsLoaded then
		PluginIsLoaded = true;
		Plugins["PerCharWallet"].Unload = function(self,sender,args)
			UnloadMe();
		end
	end

	local size = currentWallet:GetSize();

	if size ~= walletSize then
	
		walletSize=size;
		
		for i = 1, size do
		
			local walletItem = currentWallet:GetItem(i);
			
			if walletItem:IsAccountItem() then
			
				local walletItemName = walletItem:GetName();
				
				if currencyPreviousValues[walletItemName] == nil then
				
					currencyPreviousValues[walletItemName] = walletItem:GetQuantity();
				
				end
				
				if QCCallbackHandlers[walletItem] == nil then
				
					QCCallbackHandlers[walletItem] = function(sender, args) UpdateCurrencyQuantity(walletItemName); end;
					
					AddCallback(walletItem, "QuantityChanged", QCCallbackHandlers[walletItem]);
					
				end

			end
			
		end
		
		UpdateCurrencyList();
		
	end
	
end
pcwDisplayWindow:SetWantsUpdates(true);


function UpdateCurrencyQuantity(currName)

	local walletItem = GetWalletItemByName(currName);
	local amountNow = walletItem:GetQuantity();
	local amountAdded = amountNow - currencyPreviousValues[currName];
	
	currencyPreviousValues[currName] = amountNow;
	
	AssignCurrency(currentCharacterName, currName, amountAdded);
	
	if pcwDisplayWindow:IsVisible() then
	
		UpdateDisplayWindowValues();
	
	end
	
	if pcwSetupWindow:IsVisible() then
		
		if pcwSetupWindow.CurrDropDown:GetText() == currName then
	
			UpdateSetupWindowValues();
			
		end
	
	end
	
end

-------------------------------------------------------------------------------------------------

pcwDisplayWindow.CurrencyLabels = {};
pcwDisplayWindow.AmountLabels = {};
pcwDisplayWindow.TotalLabels = {};

function UpdateDisplayWindowValues()

	local NumItems = 0;
	
	for i = 1, currentWallet:GetSize() do
	
		local walletItem = currentWallet:GetItem(i);
		
		if walletItem:IsAccountItem() then
		
			NumItems = NumItems + 1;
		
			local walletItemName = walletItem:GetName();
			local walletItemQuantity = walletItem:GetQuantity();
			
			local currencyItem = GetItemFromArrayByName(currencyList, walletItemName);
			local CharacterAssignments = currencyItem.Assignments;
			local Assignment = GetItemFromArrayByName(CharacterAssignments, currentCharacterName);

			local LabelHeight = (22 * NumItems) + 70;

			if pcwDisplayWindow.CurrencyLabels[NumItems] == nil then
			
				pcwDisplayWindow.CurrencyLabels[NumItems] = Turbine.UI.Label(); 
				pcwDisplayWindow.CurrencyLabels[NumItems]:SetParent(pcwDisplayWindow); 
				pcwDisplayWindow.CurrencyLabels[NumItems]:SetPosition(20, LabelHeight); 
				pcwDisplayWindow.CurrencyLabels[NumItems]:SetSize(120,20); 
				pcwDisplayWindow.CurrencyLabels[NumItems]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
				
			end
			
			if pcwDisplayWindow.AmountLabels[NumItems] == nil then
			
				pcwDisplayWindow.AmountLabels[NumItems] = Turbine.UI.Label(); 
				pcwDisplayWindow.AmountLabels[NumItems]:SetParent(pcwDisplayWindow); 
				pcwDisplayWindow.AmountLabels[NumItems]:SetPosition(140, LabelHeight); 
				pcwDisplayWindow.AmountLabels[NumItems]:SetSize(70,20); 
				pcwDisplayWindow.AmountLabels[NumItems]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight); 
				
			end
			
			if pcwDisplayWindow.TotalLabels[NumItems] == nil then
			
				pcwDisplayWindow.TotalLabels[NumItems] = Turbine.UI.Label(); 
				pcwDisplayWindow.TotalLabels[NumItems]:SetParent(pcwDisplayWindow); 
				pcwDisplayWindow.TotalLabels[NumItems]:SetPosition(210, LabelHeight); 
				pcwDisplayWindow.TotalLabels[NumItems]:SetSize(70,20); 
				pcwDisplayWindow.TotalLabels[NumItems]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
				pcwDisplayWindow.TotalLabels[NumItems]:SetForeColor(Turbine.UI.Color(0.4, 0.4, 0.4));				
				
			end
			
			pcwDisplayWindow.CurrencyLabels[NumItems]:SetText(walletItemName);
			pcwDisplayWindow.AmountLabels[NumItems]:SetText(Assignment.Amount);
			pcwDisplayWindow.TotalLabels[NumItems]:SetText(" / " .. walletItemQuantity);

			pcwDisplayWindow.CurrencyLabels[NumItems]:SetVisible(true);
			pcwDisplayWindow.AmountLabels[NumItems]:SetVisible(true);
			pcwDisplayWindow.TotalLabels[NumItems]:SetVisible(true);
			
			if Assignment.Amount < 0 then
			
				pcwDisplayWindow.AmountLabels[NumItems]:SetForeColor(Turbine.UI.Color(1,0,0));
			
			else
			
				pcwDisplayWindow.AmountLabels[NumItems]:SetForeColor(Turbine.UI.Color(1,1,1));
			
			end
			
		end
		
	end
	
	-- remove (well, make invisible) excess labels if number of items ever decreases
	for i=1, 100 do  
	-- the 100 is just an arbitrarily large number to make "for" act like "while", 
	-- with a break when reaching nil
	
		NumItems = NumItems + 1;
		
		if pcwDisplayWindow.CurrencyLabels[NumItems] == nil then
		
			break;
		
		else
		
			pcwDisplayWindow.CurrencyLabels[NumItems]:SetVisible(false);
			pcwDisplayWindow.AmountLabels[NumItems]:SetVisible(false);
			pcwDisplayWindow.TotalLabels[NumItems]:SetVisible(false);
		
		end
	
	end
	
end

-------------------------------------------------------------------------------------------------

pcwDisplayWindow.SetupButton = Turbine.UI.Lotro.Button();
pcwDisplayWindow.SetupButton:SetParent( pcwDisplayWindow );
pcwDisplayWindow.SetupButton:SetPosition(20,60);
pcwDisplayWindow.SetupButton:SetSize(100,20);
pcwDisplayWindow.SetupButton:SetText("Assignments");
pcwDisplayWindow.SetupButton.MouseClick = function()
	
	pcwSetupWindow:SetVisible(true);
	
end
